about summary refs log tree commit diff
diff options
context:
space:
mode:
authorEelco Dolstra <edolstra@gmail.com>2017-07-31T08·31+0200
committerEelco Dolstra <edolstra@gmail.com>2017-07-31T08·31+0200
commita2778988f2b70a5f000202afa7213b553350c72e (patch)
tree34d3273caa322a0928f683ecc836423c33c1b8b8
parent561e977f51c1d9ec55e4a70791958d4e214df465 (diff)
parentfcb8d6a7a088622022364bde6534b2e4e804e4ed (diff)
Merge branch 'macOS' of https://github.com/davidak/nix
-rw-r--r--doc/manual/command-ref/conf-file.xml2
-rw-r--r--doc/manual/installation/installing-binary.xml4
-rw-r--r--doc/manual/installation/multi-user.xml2
-rw-r--r--doc/manual/installation/supported-platforms.xml2
-rw-r--r--doc/manual/introduction/about-nix.xml2
-rw-r--r--src/build-remote/build-remote.cc2
-rw-r--r--src/libstore/optimise-store.cc4
-rw-r--r--src/libutil/archive.cc2
8 files changed, 10 insertions, 10 deletions
diff --git a/doc/manual/command-ref/conf-file.xml b/doc/manual/command-ref/conf-file.xml
index 3512777dd71d..47ceff2625ea 100644
--- a/doc/manual/command-ref/conf-file.xml
+++ b/doc/manual/command-ref/conf-file.xml
@@ -262,7 +262,7 @@ false</literal>.</para>
     system (except that fixed-output derivations do not run in private
     network namespace to ensure they can access the network).</para>
 
-    <para>Currently, sandboxing only work on Linux and Mac OS X. The use
+    <para>Currently, sandboxing only work on Linux and macOS. The use
     of a sandbox requires that Nix is run as root (so you should use
     the <link linkend='conf-build-users-group'>“build users”
     feature</link> to perform the actual builds under different users
diff --git a/doc/manual/installation/installing-binary.xml b/doc/manual/installation/installing-binary.xml
index 2a9beec98c9b..24e76eafeb18 100644
--- a/doc/manual/installation/installing-binary.xml
+++ b/doc/manual/installation/installing-binary.xml
@@ -6,7 +6,7 @@
 
 <title>Installing a Binary Distribution</title>
 
-<para>If you are using Linux or Mac OS X, the easiest way to install
+<para>If you are using Linux or macOS, the easiest way to install
 Nix is to run the following command:
 
 <screen>
@@ -39,7 +39,7 @@ behaviour.
 <!--
 <para>You can also manually download and install a binary package.
 Binary packages of the latest stable release are available for Fedora,
-Debian, Ubuntu, Mac OS X and various other systems from the <link
+Debian, Ubuntu, macOS and various other systems from the <link
 xlink:href="http://nixos.org/nix/download.html">Nix homepage</link>.
 You can also get builds of the latest development release from our
 <link
diff --git a/doc/manual/installation/multi-user.xml b/doc/manual/installation/multi-user.xml
index 49c4f723597e..a13e3c89be78 100644
--- a/doc/manual/installation/multi-user.xml
+++ b/doc/manual/installation/multi-user.xml
@@ -52,7 +52,7 @@ This creates 10 build users. There can never be more concurrent builds
 than the number of build users, so you may want to increase this if
 you expect to do many builds at the same time.</para>
 
-<para>On Mac OS X, you can create the required group and users by
+<para>On macOS, you can create the required group and users by
 running the following script:
 
 <programlisting>
diff --git a/doc/manual/installation/supported-platforms.xml b/doc/manual/installation/supported-platforms.xml
index cbe528690cd9..a468a5640637 100644
--- a/doc/manual/installation/supported-platforms.xml
+++ b/doc/manual/installation/supported-platforms.xml
@@ -12,7 +12,7 @@
 
   <listitem><para>Linux (i686, x86_64).</para></listitem>
 
-  <listitem><para>Mac OS X (x86_64).</para></listitem>
+  <listitem><para>macOS (x86_64).</para></listitem>
 
   <!--
   <listitem><para>FreeBSD (only tested on Intel).</para></listitem>
diff --git a/doc/manual/introduction/about-nix.xml b/doc/manual/introduction/about-nix.xml
index be065da3eb2d..7cb124033f3e 100644
--- a/doc/manual/introduction/about-nix.xml
+++ b/doc/manual/introduction/about-nix.xml
@@ -236,7 +236,7 @@ href="[%root%]hydra">a continuous build system</a>.</para>
 
 <simplesect><title>Portability</title>
 
-<para>Nix runs on Linux and Mac OS X.</para>
+<para>Nix runs on Linux and macOS.</para>
 
 </simplesect>
 
diff --git a/src/build-remote/build-remote.cc b/src/build-remote/build-remote.cc
index d433e24913f7..4b7a24d03e9a 100644
--- a/src/build-remote/build-remote.cc
+++ b/src/build-remote/build-remote.cc
@@ -57,7 +57,7 @@ int main (int argc, char * * argv)
         settings.builders = argv[5];
 
         /* It would be more appropriate to use $XDG_RUNTIME_DIR, since
-           that gets cleared on reboot, but it wouldn't work on OS X. */
+           that gets cleared on reboot, but it wouldn't work on macOS. */
         currentLoad = settings.nixStateDir + "/current-load";
 
         std::shared_ptr<Store> sshStore;
diff --git a/src/libutil/archive.cc b/src/libutil/archive.cc
index be527450c464..51b57a8f4e97 100644
--- a/src/libutil/archive.cc
+++ b/src/libutil/archive.cc
@@ -72,7 +72,7 @@ static void dump(const Path & path, Sink & sink, PathFilter & filter)
     else if (S_ISDIR(st.st_mode)) {
         sink << "type" << "directory";
 
-        /* If we're on a case-insensitive system like Mac OS X, undo
+        /* If we're on a case-insensitive system like macOS, undo
            the case hack applied by restorePath(). */
         std::map<string, string> unhacked;
         for (auto & i : readDirectory(path))
diff --git a/src/libstore/optimise-store.cc b/src/libstore/optimise-store.cc
index 4461fc6dd70d..462f8e72a8d1 100644
--- a/src/libstore/optimise-store.cc
+++ b/src/libstore/optimise-store.cc
@@ -98,14 +98,14 @@ void LocalStore::optimisePath_(OptimiseStats & stats, const Path & path, InodeHa
         throw SysError(format("getting attributes of path '%1%'") % path);
 
 #if __APPLE__
     /* HFS/OS X has some undocumented security feature disabling hardlinking for
        special files within .app dirs. *.app/Contents/PkgInfo and
        *.app/Contents/Resources/\*.lproj seem to be the only paths affected. See
        https://github.com/NixOS/nix/issues/1443 for more discussion. */
 
     if (std::regex_search(path, std::regex("\\.app/Contents/PkgInfo$")) ||
         std::regex_search(path, std::regex("\\.app/Contents/Resources/.+\\.lproj$"))) {
-        debug(format("'%1%' is not allowed to be linked in OS X") % path);
+        debug(format("'%1%' is not allowed to be linked in macOS") % path);
         return;
     }
 #endif
@@ -98,14 +98,14 @@ void LocalStore::optimisePath_(OptimiseStats & stats, const Path & path, InodeHa
 
 #if __APPLE__
-    /* HFS/OS X has some undocumented security feature disabling hardlinking for
+    /* HFS/macOS has some undocumented security feature disabling hardlinking for
        special files within .app dirs. *.app/Contents/PkgInfo and
        *.app/Contents/Resources/\*.lproj seem to be the only paths affected. See